@@ -22,27 +22,44 @@ class NotebookCommandClass(click.MultiCommand):
         click_params = []
         old_params = nbparameterise.extract_parameters(nb)
         for param in old_params:
-            # Create a help text from the given comment
-            help = param.comment
-            if help is not None:
-                # This removes the '#' from the comment
-                help = help[1:].strip()
-
             # Create the name of the flag
             flag = f"--{param.name}"
             if issubclass(param.type, bool):
                 flag = f"--{param.name}/--no-{param.name}"
 
+            # A dictionary of arguments to click.Option
+            opt_args = {}
+
+            # Default values can bet taken directly from param. We
+            # always display the defaults in --help
+            opt_args["default"] = param.value
+            opt_args["show_default"] = True
+
+            # If the parameter is a list we need to inspect the default
+            # for type information.
+            if issubclass(param.type, list):
+                types = tuple(type(item) for item in param.value)
+                if len(set(types)) == 1:
+                    # This is a list of a single type, we realize it by click's
+                    # nargs option. click does not support variable length list parameters
+                    # because they result in ambiguous parser behaviour
+                    opt_args["nargs"] = len(param.value)
+                    opt_args["type"] = types[0]
+                else:
+                    # For multi-type lists, we require all types to be present
+                    opt_args["type"] = types
+            else:
+                # Type information for scalar types can be taken from param
+                opt_args["type"] = param.type
+
+            # Create a help text from the given comment
+            opt_args["help"] = param.comment
+            if param.comment is not None:
+                # This removes the '#' from the comment
+                opt_args["help"] = param.comment[1:].strip()
+
             # Create a click option from the given parameter
-            click_params.append(
-                click.Option(
-                    (flag,),
-                    default=param.value,
-                    type=param.type,
-                    show_default=True,
-                    help=help,
-                )
-            )
+            click_params.append(click.Option((flag,), **opt_args))
 
         def callback(**parameters):
             new_params = nbparameterise.parameter_values(old_params, **parameters)
